plot_ellipse

Function plot_ellipse 

pub fn plot_ellipse(from: Coordinate, to: Coordinate) -> Vec<Coordinate>
Draws a line between two coordinate points in the form on a ellipse.

Derived from: https://en.wikipedia.org/wiki/Ellipse

Experimental

This functionality is heavily a work in progress and it’s behaviour is unreliable.